@@ -88,7 +88,7 @@ public:
 // user defined declarations:
 public:
 
-# 143 "/build/kdevelop-php/src/kdev-php-23.04.3/parser/php.g" 1
+# 150 "/build/kdevelop-php/src/kdev-php-23.08.0/parser/php.g" 1
 
     /**
      * Transform the raw input into tokens.
@@ -121,10 +121,18 @@ public:
         DefaultState = 1
     };
 
+    enum ParserUseImportType
+    {
+        NamespaceOrClassImport,
+        ConstantImport,
+        FunctionImport
+    };
+    ParserUseImportType m_useImportType;
+    ParserUseImportType m_useCompoundImportType;
 
 private:
 
-# 175 "/build/kdevelop-php/src/kdev-php-23.04.3/parser/php.g" 1
+# 189 "/build/kdevelop-php/src/kdev-php-23.08.0/parser/php.g" 1
 
     enum VarExpressionState
     {
@@ -169,7 +177,7 @@ public:
 
 // user defined constructor code:
 
-# 196 "/build/kdevelop-php/src/kdev-php-23.04.3/parser/php.g" 1
+# 210 "/build/kdevelop-php/src/kdev-php-23.08.0/parser/php.g" 1
 
         m_state.varExpressionState = Normal;
         m_state.varExpressionIsVariable = false;
@@ -211,6 +219,8 @@ public:
     bool parseClassVariableDeclaration(ClassVariableDeclarationAst **yynode);
     bool parseClosure(ClosureAst **yynode);
     bool parseCommonScalar(CommonScalarAst **yynode);
+    bool parseCompoundNamespace(CompoundNamespaceAst **yynode);
+    bool parseCompoundNamespaceStatement(CompoundNamespaceStatementAst **yynode);
     bool parseCompoundVariable(CompoundVariableAst **yynode);
     bool parseCompoundVariableWithSimpleIndirectReference(CompoundVariableWithSimpleIndirectReferenceAst **yynode);
     bool parseConditionalExpression(ConditionalExpressionAst **yynode);
@@ -243,6 +253,7 @@ public:
     bool parseIdentifier(IdentifierAst **yynode);
     bool parseIifeSyntax(IifeSyntaxAst **yynode);
     bool parseInnerStatementList(InnerStatementListAst **yynode);
+    bool parseInnerUseNamespace(InnerUseNamespaceAst **yynode);
     bool parseInstantiationAccess(InstantiationAccessAst **yynode);
     bool parseInterfaceDeclarationStatement(InterfaceDeclarationStatementAst **yynode);
     bool parseLexicalVar(LexicalVarAst **yynode);
@@ -255,6 +266,7 @@ public:
     bool parseMultiplicativeExpressionRest(MultiplicativeExpressionRestAst **yynode);
     bool parseNamespaceDeclarationStatement(NamespaceDeclarationStatementAst **yynode);
     bool parseNamespacedIdentifier(NamespacedIdentifierAst **yynode);
+    bool parseNamespacedIdentifierBeforeGroupedNamespace(NamespacedIdentifierBeforeGroupedNamespaceAst **yynode);
     bool parseNewElseSingle(NewElseSingleAst **yynode);
     bool parseNewElseifList(NewElseifListAst **yynode);
     bool parseNewelseifListItem(NewelseifListItemAst **yynode);
@@ -300,7 +312,7 @@ public:
     bool parseTraitVisibilityModifiers(TraitVisibilityModifiersAst **yynode);
     bool parseUnaryExpression(UnaryExpressionAst **yynode);
     bool parseUnaryExpressionNotPlusminus(UnaryExpressionNotPlusminusAst **yynode);
-    bool parseUseNamespace(UseNamespaceAst **yynode);
+    bool parseUseNamespaceOrUseGroupedNamespace(UseNamespaceOrUseGroupedNamespaceAst **yynode);
     bool parseUseStatement(UseStatementAst **yynode);
     bool parseVarExpression(VarExpressionAst **yynode);
     bool parseVarExpressionArray(VarExpressionArrayAst **yynode);
